[gobject-introspection] [GIRepository] Rename GArgument to GIArgument



commit 6379b8a497e2bf8c5b09e37ded88c7a28483389d
Author: Johan Dahlin <johan gnome org>
Date:   Tue Aug 31 17:33:06 2010 -0300

    [GIRepository] Rename GArgument to GIArgument
    
    Keep a typedef for backwards compatibility, until
    the major bindings has moved over.

 examples/glib-print.c           |    6 +++---
 girepository/giconstantinfo.c   |    2 +-
 girepository/giconstantinfo.h   |    2 +-
 girepository/gifieldinfo.c      |    8 ++++----
 girepository/gifieldinfo.h      |    4 ++--
 girepository/gifunctioninfo.c   |   10 +++++-----
 girepository/gifunctioninfo.h   |    6 +++---
 girepository/girwriter.c        |    8 ++++----
 girepository/gitypes.h          |    7 ++++++-
 tests/repository/gitestthrows.c |    4 ++--
 10 files changed, 31 insertions(+), 26 deletions(-)
---
diff --git a/examples/glib-print.c b/examples/glib-print.c
index 7f99ed1..f187f76 100644
--- a/examples/glib-print.c
+++ b/examples/glib-print.c
@@ -5,8 +5,8 @@ int main(void)
     GIRepository *repository;
     GError *error = NULL;
     GIBaseInfo *base_info;
-    GArgument in_args[5];
-    GArgument retval;
+    GIArgument in_args[5];
+    GIArgument retval;
 
     g_type_init();
 
@@ -30,7 +30,7 @@ int main(void)
     in_args[4].v_pointer = "hello world";
 
     if (!g_function_info_invoke ((GIFunctionInfo *)base_info,
-                                 (const GArgument*)&in_args,
+                                 (const GIArgument*)&in_args,
                                  5,
                                  NULL,
                                  0,
diff --git a/girepository/giconstantinfo.c b/girepository/giconstantinfo.c
index 58b223f..ea7d416 100644
--- a/girepository/giconstantinfo.c
+++ b/girepository/giconstantinfo.c
@@ -77,7 +77,7 @@ g_constant_info_get_type (GIConstantInfo *info)
  */
 gint
 g_constant_info_get_value (GIConstantInfo *info,
-			   GArgument      *value)
+			   GIArgument      *value)
 {
   GIRealInfo *rinfo = (GIRealInfo *)info;
   ConstantBlob *blob;
diff --git a/girepository/giconstantinfo.h b/girepository/giconstantinfo.h
index eea0f66..a2679bd 100644
--- a/girepository/giconstantinfo.h
+++ b/girepository/giconstantinfo.h
@@ -35,7 +35,7 @@ G_BEGIN_DECLS
 
 GITypeInfo * g_constant_info_get_type (GIConstantInfo *info);
 gint         g_constant_info_get_value(GIConstantInfo *info,
-				       GArgument      *value);
+				       GIArgument      *value);
 G_END_DECLS
 
 
diff --git a/girepository/gifieldinfo.h b/girepository/gifieldinfo.h
index 53ff9be..589221b 100644
--- a/girepository/gifieldinfo.h
+++ b/girepository/gifieldinfo.h
@@ -39,10 +39,10 @@ gint                   g_field_info_get_offset     (GIFieldInfo *info);
 GITypeInfo *           g_field_info_get_type       (GIFieldInfo *info);
 gboolean               g_field_info_get_field      (GIFieldInfo     *field_info,
 						    gpointer         mem,
-						    GArgument       *value);
+						    GIArgument       *value);
 gboolean               g_field_info_set_field      (GIFieldInfo     *field_info,
 						    gpointer         mem,
-						    const GArgument *value);
+						    const GIArgument *value);
 
 G_END_DECLS
 
diff --git a/girepository/gifunctioninfo.h b/girepository/gifunctioninfo.h
index a07b60f..b2fa1f7 100644
--- a/girepository/gifunctioninfo.h
+++ b/girepository/gifunctioninfo.h
@@ -61,11 +61,11 @@ typedef enum
 } GInvokeError;
 
 gboolean              g_function_info_invoke         (GIFunctionInfo *info,
-						      const GArgument  *in_args,
+						      const GIArgument  *in_args,
 						      int               n_in_args,
-						      const GArgument  *out_args,
+						      const GIArgument  *out_args,
 						      int               n_out_args,
-						      GArgument        *return_value,
+						      GIArgument        *return_value,
 						      GError          **error);
 
 
diff --git a/girepository/girwriter.c b/girepository/girwriter.c
index bf7ea9d..48f1a5d 100644
--- a/girepository/girwriter.c
+++ b/girepository/girwriter.c
@@ -389,7 +389,7 @@ write_return_value_attributes (Xml *file,
 static void
 write_constant_value (const gchar *namespace,
 		      GITypeInfo *info,
-		      GArgument *argument,
+		      GIArgument *argument,
 		      Xml *file);
 
 static void
@@ -409,7 +409,7 @@ write_field_info (const gchar *namespace,
   gint offset;
   GITypeInfo *type;
   GIBaseInfo *interface;
-  GArgument value;
+  GIArgument value;
 
   name = g_base_info_get_name ((GIBaseInfo *)info);
   flags = g_field_info_get_flags (info);
@@ -725,7 +725,7 @@ write_value_info (const gchar *namespace,
 static void
 write_constant_value (const gchar *namespace,
 		      GITypeInfo *type,
-		      GArgument  *value,
+		      GIArgument  *value,
 		      Xml        *file)
 {
   switch (g_type_info_get_tag (type))
@@ -780,7 +780,7 @@ write_constant_info (const gchar    *namespace,
   GITypeInfo *type;
   const gchar *name;
   gboolean deprecated;
-  GArgument value;
+  GIArgument value;
 
   name = g_base_info_get_name ((GIBaseInfo *)info);
   deprecated = g_base_info_is_deprecated ((GIBaseInfo *)info);
diff --git a/girepository/gitypes.h b/girepository/gitypes.h
index eb1c102..882f00f 100644
--- a/girepository/gitypes.h
+++ b/girepository/gitypes.h
@@ -187,7 +187,7 @@ typedef union
   gsize    v_size;
   gchar *  v_string;
   gpointer v_pointer;
-} GArgument;
+} GIArgument;
 
 /**
  * GIInfoType:
@@ -438,6 +438,11 @@ typedef enum
   GI_FUNCTION_THROWS         = 1 << 5
 } GIFunctionInfoFlags;
 
+#ifndef __GI_SCANNER__
+/* backwards compatibility */
+typedef union GIArgument GArgument;
+#endif
+
 G_END_DECLS
 
 #endif  /* __GITYPES_H__ */
diff --git a/tests/repository/gitestthrows.c b/tests/repository/gitestthrows.c
index 9bc7ec1..5c1ffe5 100644
--- a/tests/repository/gitestthrows.c
+++ b/tests/repository/gitestthrows.c
@@ -12,8 +12,8 @@ main(int argc, char **argv)
   GTypelib *ret;
   GIBaseInfo *info;
   char *girdir;
-  GArgument in_arg[1];
-  GArgument ret_arg;
+  GIArgument in_arg[1];
+  GIArgument ret_arg;
   GError *error;
   gboolean invoke_return;
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/girepository/gifieldinfo.c b/girepository/gifieldinfo.c
index 9862a72..4acc8e3 100644
--- a/girepository/gifieldinfo.c
+++ b/girepository/gifieldinfo.c
@@ -164,7 +164,7 @@ g_field_info_get_type (GIFieldInfo *info)
  * g_field_info_get_field:
  * @field_info: a #GIFieldInfo
  * @mem: pointer to a block of memory representing a C structure or union
  * @value: a #GArgument into which to store the value retrieved
  *
  * Reads a field identified by a #GFieldInfo from a C structure or
  * union.  This only handles fields of simple C types. It will fail
@@ -176,7 +176,7 @@ g_field_info_get_type (GIFieldInfo *info)
 gboolean
 g_field_info_get_field (GIFieldInfo *field_info,
 			gpointer     mem,
-			GArgument   *value)
+			GIArgument   *value)
 {
   int offset;
   GITypeInfo *type_info;
@@ -346,7 +346,7 @@ g_field_info_get_field (GIFieldInfo *field_info,
  * g_field_info_set_field:
  * @field_info: a #GIFieldInfo
  * @mem: pointer to a block of memory representing a C structure or union
  * @value: a #GArgument holding the value to store
  *
  * Writes a field identified by a #GFieldInfo to a C structure or
  * union.  This only handles fields of simple C types. It will fail
@@ -360,7 +360,7 @@ g_field_info_get_field (GIFieldInfo *field_info,
 gboolean
 g_field_info_set_field (GIFieldInfo     *field_info,
 			gpointer         mem,
-			const GArgument *value)
+			const GIArgument *value)
 {
   int offset;
   GITypeInfo *type_info;
@@ -164,7 +164,7 @@ g_field_info_get_type (GIFieldInfo *info)
  * @field_info: a #GIFieldInfo
  * @mem: pointer to a block of memory representing a C structure or union
- * @value: a #GArgument into which to store the value retrieved
+ * @value: a #GIArgument into which to store the value retrieved
  *
  * Reads a field identified by a #GFieldInfo from a C structure or
@@ -346,7 +346,7 @@ g_field_info_get_field (GIFieldInfo *field_info,
  * @field_info: a #GIFieldInfo
  * @mem: pointer to a block of memory representing a C structure or union
- * @value: a #GArgument holding the value to store
+ * @value: a #GIArgument holding the value to store
  *
  * Writes a field identified by a #GFieldInfo to a C structure or
diff --git a/girepository/gifunctioninfo.c b/girepository/gifunctioninfo.c
index 7365370..9dd6daa 100644
--- a/girepository/gifunctioninfo.c
+++ b/girepository/gifunctioninfo.c
@@ -217,11 +217,11 @@ g_invoke_error_quark (void)
 /**
  * g_function_info_invoke:
  * @info: a #GIFunctionInfo describing the function to invoke
  * @in_args: an array of #GArgument<!-- -->s, one for each in
  *    parameter of @info. If there are no in parameter, @in_args
  *    can be %NULL
  * @n_in_args: the length of the @in_args array
  * @out_args: an array of #GArgument<!-- -->s, one for each out
  *    parameter of @info. If there are no out parameters, @out_args
  *    may be %NULL
  * @n_out_args: the length of the @out_args array
@@ -242,11 +242,11 @@ g_invoke_error_quark (void)
  */
 gboolean
 g_function_info_invoke (GIFunctionInfo *info,
-			const GArgument  *in_args,
+			const GIArgument  *in_args,
 			int               n_in_args,
-			const GArgument  *out_args,
+			const GIArgument  *out_args,
 			int               n_out_args,
-			GArgument        *return_value,
+			GIArgument        *return_value,
 			GError          **error)
 {
   ffi_cif cif;
@@ -217,11 +217,11 @@ g_invoke_error_quark (void)
  * g_function_info_invoke:
  * @info: a #GIFunctionInfo describing the function to invoke
- * @in_args: an array of #GArgument<!-- -->s, one for each in
+ * @in_args: an array of #GIArgument<!-- -->s, one for each in
  *    parameter of @info. If there are no in parameter, @in_args
  *    can be %NULL
@@ -217,11 +217,11 @@ g_invoke_error_quark (void)
  *    can be %NULL
  * @n_in_args: the length of the @in_args array
- * @out_args: an array of #GArgument<!-- -->s, one for each out
+ * @out_args: an array of #GIArgument<!-- -->s, one for each out
  *    parameter of @info. If there are no out parameters, @out_args
  *    may be %NULL